@@ -7,7 +7,7 @@ from xklb import consts, db, player, tube_backend, utils
 from xklb.consts import SC
 from xklb.player import get_ordinal_media, mark_media_deleted, override_sort
 from xklb.subtitle import externalize_subtitle
-from xklb.utils import cmd, log
+from xklb.utils import cmd, human_to_bytes, log
 
 
 def usage(action, default_db) -> str:
@@ -221,45 +221,6 @@ def usage(action, default_db) -> str:
 """
 
 
-def parse_size(size):
-    B_TO_MB = 1024 * 1024
-    size_mb = 0
-    size_rules = ""
-
-    for size_rule in size:
-        if "+" in size_rule:
-            # min size rule
-            size_rules += f"and size >= {abs(int(size_rule)) * B_TO_MB} "
-        elif "-" in size_rule:
-            # max size rule
-            size_rules += f"and {abs(int(size_rule)) * B_TO_MB} >= size "
-        else:
-            # approximate size rule
-            size_mb = float(size_rule) * B_TO_MB
-            size_rules += f"and {size_mb + (size_mb /10)} >= size and size >= {size_mb - (size_mb /10)} "
-    return size_rules
-
-
-def parse_duration(args):
-    SEC_FROM_M = 60
-    duration_m = 0
-    duration_rules = ""
-
-    for duration_rule in args.duration:
-        if "+" in duration_rule:
-            # min duration rule
-            duration_rules += f"and duration >= {int(abs(float(duration_rule)) * SEC_FROM_M)} "
-        elif "-" in duration_rule:
-            # max duration rule
-            duration_rules += f"and {int(abs(float(duration_rule)) * SEC_FROM_M)} >= duration "
-        else:
-            # approximate duration rule
-            duration_m = float(duration_rule) * SEC_FROM_M
-            duration_rules += f"and {int(duration_m + (duration_m /10))} >= duration and duration >= {int(duration_m - (duration_m /10))} "
-
-    return duration_rules
-
-
 def parse_args_sort(args, action):
     if args.sort:
         args.sort = " ".join(args.sort).split(",")
@@ -333,7 +294,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--prefix", default="", help=argparse.SUPPRESS)
 
     parser.add_argument("--duration", "-d", action="append", help=argparse.SUPPRESS)
-    parser.add_argument("--size", "-z", action="append", help=argparse.SUPPRESS)
+    parser.add_argument("--size", "-S", action="append", help=argparse.SUPPRESS)
     parser.add_argument("--duration-from-size", action="append", help=argparse.SUPPRESS)
 
     parser.add_argument("--print", "-p", default=False, const="p", nargs="?", help=argparse.SUPPRESS)
@@ -341,7 +302,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
 
     parser.add_argument("--cols", "-cols", "-col", nargs="*", help=argparse.SUPPRESS)
     parser.add_argument("--limit", "-L", "-queue", "--queue", help=argparse.SUPPRESS)
-    parser.add_argument("--skip", "-S", help=argparse.SUPPRESS)
+    parser.add_argument("--skip", "--offset", help=argparse.SUPPRESS)
     parser.add_argument(
         "--partial", "-P", "--recent", "-R", default=False, const="n", nargs="?", help=argparse.SUPPRESS
     )
@@ -400,13 +361,13 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
         args.cols = list(utils.flatten([s.split(",") for s in args.cols]))
 
     if args.duration:
-        args.duration = parse_duration(args)
+        args.duration = utils.parse_human_to_sql(utils.human_to_seconds, "duration", args.duration)
 
     if args.size:
-        args.size = parse_size(args.size)
+        args.size = utils.parse_human_to_sql(utils.human_to_bytes, "size", args.size)
 
     if args.duration_from_size:
-        args.duration_from_size = parse_size(args.duration_from_size)
+        args.duration_from_size = utils.parse_human_to_sql(utils.human_to_bytes, "size", args.duration_from_size)
 
     if args.chromecast:
         from catt.api import CattDevice
